@@ -1,10 +1,15 @@
 package Data::Money::Types;
+use warnings;
+use strict;
 
 use MooseX::Types -declare => [ qw(Amount CurrencyCode DataMoney Format) ];
 
 use MooseX::Types::Moose qw(Num Str Undef);
 use Locale::Currency qw(code2currency);
 
+use vars qw/$VERSION/;
+$VERSION = '0.04';
+
 class_type Amount, { class => 'Math::BigFloat' };
 class_type DataMoney, { class => 'Data::Money' };
 
@@ -17,8 +22,11 @@ coerce Amount,
     via {
         # strip out formatting characters
         $_ =~ tr/-()0-9.//cd;
-        $_ = 0 unless($_);
-        Math::BigFloat->new($_)
+        if($_) {
+            Math::BigFloat->new($_)
+        } else {
+            Math::BigFloat->new(0)
+        }
     };
 
 coerce Amount,
@@ -31,7 +39,7 @@ coerce Amount,
 
 subtype CurrencyCode,
     as Str,
-    where { !defined($_) || ($_ =~ /^[A-Z]{3}$/ && defined(code2currency($_))) },
+    where { !defined $_ || ($_ =~ /^[A-Z]{3}$/mxs && defined code2currency($_)) },
     message { 'String is not a valid 3 letter currency code.' };
 
 enum Format,
